@@ -63,18 +63,44 @@ impl AppTimer for StandardAppTimer {
     }
 }
 
+pub struct AppParams(HashMap<String, String>);
+
+impl AppParams {
+    pub fn new(data: HashMap<String, String>) -> Self {
+        Self(data)
+    }
+
+    pub fn params(&self) -> &HashMap<String, String> {
+        &self.0
+    }
+
+    pub fn get(&self, name: &str) -> Option<&str> {
+        self.0.get(name).map(|v| v.as_str())
+    }
+
+    pub fn has(&self, name: &str) -> bool {
+        self.0.contains_key(name)
+    }
+}
+
 pub struct AppLifeCycle {
     pub running: bool,
+    pub delta_time_limit: Option<Duration>,
     pub(crate) timer: Box<dyn AppTimer>,
     pub(crate) states_tokens: Vec<StateToken>,
 }
 
 impl AppLifeCycle {
     pub fn new(timer: Box<dyn AppTimer>) -> Self {
+        Self::with_limit(timer, None)
+    }
+
+    pub fn with_limit(timer: Box<dyn AppTimer>, delta_time_limit: Option<Duration>) -> Self {
         Self {
             running: true,
             timer,
             states_tokens: vec![StateToken::new()],
+            delta_time_limit,
         }
     }
 
@@ -83,11 +109,25 @@ impl AppLifeCycle {
     }
 
     pub fn delta_time(&self) -> Duration {
-        self.timer.delta_time()
+        let dt = self.timer.delta_time();
+        match self.delta_time_limit {
+            Some(limit) => dt.min(limit),
+            None => dt,
+        }
     }
 
     pub fn delta_time_seconds(&self) -> Scalar {
-        self.timer.delta_time_seconds()
+        let dt = self.timer.delta_time_seconds();
+        match self.delta_time_limit {
+            Some(limit) => {
+                #[cfg(feature = "scalar64")]
+                let limit = limit.as_secs_f64();
+                #[cfg(not(feature = "scalar64"))]
+                let limit = limit.as_secs_f32();
+                dt.min(limit)
+            }
+            None => dt,
+        }
     }
 
     pub fn current_state_token(&self) -> StateToken {
@@ -99,6 +139,24 @@ impl AppLifeCycle {
     }
 }
 
+impl<AT> From<AT> for AppLifeCycle
+where
+    AT: AppTimer + 'static,
+{
+    fn from(timer: AT) -> Self {
+        AppLifeCycle::new(Box::new(timer))
+    }
+}
+
+impl<AT> From<(AT, Duration)> for AppLifeCycle
+where
+    AT: AppTimer + 'static,
+{
+    fn from((timer, delta_time_limit): (AT, Duration)) -> Self {
+        AppLifeCycle::with_limit(Box::new(timer), Some(delta_time_limit))
+    }
+}
+
 pub struct AppRunner {
     pub app: Rc<RefCell<App>>,
 }
@@ -203,6 +261,7 @@ where
             entity_life_cycle_system,
             &[],
             PipelineLayer::Pre,
+            false,
         )
         .expect("Could not install entity-life-cycle system!")
         .with_resource(Hierarchy::default())
@@ -211,6 +270,7 @@ where
             hierarchy_system,
             &["entity-life-cycle"],
             PipelineLayer::Pre,
+            false,
         )
         .expect("Could not install hierarchy system!")
     }
@@ -270,9 +330,15 @@ where
         system: System,
         dependencies: &[&str],
         layer: PipelineLayer,
+        lock_on_single_thread: bool,
     ) -> Result<(), PipelineBuilderError> {
-        self.pipeline_builder
-            .add_system_on_layer::<AT>(name, system, dependencies, layer)?;
+        self.pipeline_builder.add_system_on_layer::<AT>(
+            name,
+            system,
+            dependencies,
+            layer,
+            lock_on_single_thread,
+        )?;
         Ok(())
     }
 
@@ -288,6 +354,18 @@ where
         Ok(())
     }
 
+    #[inline]
+    pub fn install_system_on_single_thread<AT: AccessType>(
+        &mut self,
+        name: &str,
+        system: System,
+        dependencies: &[&str],
+    ) -> Result<(), PipelineBuilderError> {
+        self.pipeline_builder
+            .add_system_on_single_thread::<AT>(name, system, dependencies)?;
+        Ok(())
+    }
+
     #[inline]
     pub fn with_system_on_layer<AT: AccessType>(
         mut self,
@@ -295,8 +373,15 @@ where
         system: System,
         dependencies: &[&str],
         layer: PipelineLayer,
+        lock_on_single_thread: bool,
     ) -> Result<Self, PipelineBuilderError> {
-        self.install_system_on_layer::<AT>(name, system, dependencies, layer)?;
+        self.install_system_on_layer::<AT>(
+            name,
+            system,
+            dependencies,
+            layer,
+            lock_on_single_thread,
+        )?;
         Ok(self)
     }
 
@@ -312,22 +397,33 @@ where
     }
 
     #[inline]
-    pub fn build<P, S, AT>(self, state: S, app_timer: AT) -> App
+    pub fn with_system_on_single_thread<AT: AccessType>(
+        mut self,
+        name: &str,
+        system: System,
+        dependencies: &[&str],
+    ) -> Result<Self, PipelineBuilderError> {
+        self.install_system_on_single_thread::<AT>(name, system, dependencies)?;
+        Ok(self)
+    }
+
+    #[inline]
+    pub fn build<P, S, AL>(self, state: S, life_cycle: AL) -> App
     where
         P: PipelineEngine + Send + Sync + Default + 'static,
         S: State + 'static,
-        AT: AppTimer + 'static,
+        AL: Into<AppLifeCycle>,
     {
-        self.build_with_engine(P::default(), state, app_timer)
+        self.build_with_engine(P::default(), state, life_cycle)
     }
 
-    pub fn build_with_engine<P, S, AT>(mut self, engine: P, state: S, app_timer: AT) -> App
+    pub fn build_with_engine<P, S, AL>(mut self, engine: P, state: S, life_cycle: AL) -> App
     where
         P: PipelineEngine + Send + Sync + 'static,
         S: State + 'static,
-        AT: AppTimer + 'static,
+        AL: Into<AppLifeCycle>,
     {
-        self.install_resource(AppLifeCycle::new(Box::new(app_timer)));
+        self.install_resource(life_cycle.into());
         let mut multiverse =
             Multiverse::new(self.pipeline_builder.build_with_engine(engine), state);
         if let Some(universe) = multiverse.default_universe_mut() {
@@ -341,21 +437,21 @@ where
     }
 
     #[inline]
-    pub fn build_empty<P, AT>(self, app_timer: AT) -> App
+    pub fn build_empty<P, AL>(self, life_cycle: AL) -> App
     where
         P: PipelineEngine + Send + Sync + Default + 'static,
-        AT: AppTimer + 'static,
+        AL: Into<AppLifeCycle>,
     {
-        self.build::<P, _, _>((), app_timer)
+        self.build::<P, _, _>((), life_cycle)
     }
 
     #[inline]
-    pub fn build_empty_with_engine<P, AT>(self, engine: P, app_timer: AT) -> App
+    pub fn build_empty_with_engine<P, AL>(self, engine: P, life_cycle: AL) -> App
     where
         P: PipelineEngine + Send + Sync + 'static,
-        AT: AppTimer + 'static,
+        AL: Into<AppLifeCycle>,
     {
-        self.build_with_engine::<P, _, _>(engine, (), app_timer)
+        self.build_with_engine::<P, _, _>(engine, (), life_cycle)
     }
 }
 
