@@ -33,7 +33,7 @@ pub fn entity_life_cycle_system(universe: &mut Universe) {
 
     let old = std::mem::replace(
         &mut changes.entities,
-        world.iter().map(|(id, _)| id).collect(),
+        world.iter().map(|id| id.entity()).collect(),
     );
     changes.spawned = changes.entities.difference(&old).copied().collect();
     changes.despawned = old.difference(&changes.entities).copied().collect();
