@@ -210,7 +210,7 @@ fn test_entity_life_cycle() {
         assert_eq!(changes.despawned().collect::<HashSet<_>>(), set(&[]));
         let world = app.multiverse.default_universe_mut().unwrap().world_mut();
         assert_eq!(
-            world.iter().map(|(id, _)| id).collect::<HashSet<_>>(),
+            world.iter().map(|id| id.entity()).collect::<HashSet<_>>(),
             set(&[root, e1])
         );
     }
@@ -225,7 +225,7 @@ fn test_entity_life_cycle() {
         assert_eq!(&changes.despawned().collect::<Vec<_>>(), &[]);
         let world = app.multiverse.default_universe_mut().unwrap().world_mut();
         assert_eq!(
-            world.iter().map(|(id, _)| id).collect::<HashSet<_>>(),
+            world.iter().map(|id| id.entity()).collect::<HashSet<_>>(),
             set(&[root, e1])
         );
     }
@@ -233,7 +233,7 @@ fn test_entity_life_cycle() {
         let mut world = app.multiverse.default_universe_mut().unwrap().world_mut();
         let _ = world.despawn(root);
         assert_eq!(
-            world.iter().map(|(id, _)| id).collect::<HashSet<_>>(),
+            world.iter().map(|id| id.entity()).collect::<HashSet<_>>(),
             set(&[e1])
         );
     }
@@ -248,7 +248,7 @@ fn test_entity_life_cycle() {
         assert_eq!(changes.despawned().collect::<HashSet<_>>(), set(&[root]));
         let world = app.multiverse.default_universe_mut().unwrap().world_mut();
         assert_eq!(
-            world.iter().map(|(id, _)| id).collect::<HashSet<_>>(),
+            world.iter().map(|id| id.entity()).collect::<HashSet<_>>(),
             set(&[])
         );
     }
@@ -263,7 +263,7 @@ fn test_entity_life_cycle() {
         assert_eq!(changes.despawned().collect::<HashSet<_>>(), set(&[e1]));
         let world = app.multiverse.default_universe_mut().unwrap().world_mut();
         assert_eq!(
-            world.iter().map(|(id, _)| id).collect::<HashSet<_>>(),
+            world.iter().map(|id| id.entity()).collect::<HashSet<_>>(),
             set(&[])
         );
     }
